This function takes a detour object as an input, and generates a
sequence of projection matrices for the tour. The return value is another
detour object with the tour path and other metadata attached. This can
then be passed to a show_*#' function to generate the detour
visualisation.
Usage
tour_path(
x,
tour_path = grand_tour(2),
start = NULL,
aps = 1,
fps = 30,
max_bases = 10
)