Aesthetic mapping for tours describing how variables in the data are mapped to visual properties of the tour animation.
Examples
detour(tourr::flea, tour_aes(projection = -species, colour = species)) |>
tour_path(grand_tour(3), fps = 60) |>
show_scatter(alpha = 0.7, axes = FALSE)