powered by
Aesthetic mapping for tours describing how variables in the data are mapped to visual properties of the tour animation.
tour_aes(...)
a list of quosures
list of name-value pairs in the form 'aesthetic = variable'. Variables are evaluated using tidyselect syntax.
detour(tourr::flea, tour_aes(projection = -species, colour = species)) |> tour_path(grand_tour(3), fps = 60) |> show_scatter(alpha = 0.7, axes = FALSE)
Run the code above in your browser using DataLab